@@ -61,11 +61,11 @@ from .user_agent import User_Agent
 
 __version__ = '1.2.40'
 
+
 # ------------------------------------------------------------------------------- #
 
 
 class CipherSuiteAdapter(HTTPAdapter):
-
     __attrs__ = [
         'ssl_context',
         'max_retries',
@@ -99,16 +99,14 @@ class CipherSuiteAdapter(HTTPAdapter):
         kwargs['ssl_context'] = self.ssl_context
         return super(CipherSuiteAdapter, self).proxy_manager_for(*args, **kwargs)
 
+
 # ------------------------------------------------------------------------------- #
 
 
 class CloudScraper(Session):
 
-
-
     def __init__(self, *args, **kwargs):
 
-
         self.debug = kwargs.pop('debug', False)
         self.delay = kwargs.pop('delay', None)
         self.cipherSuite = kwargs.pop('cipherSuite', None)
@@ -245,9 +243,7 @@ class CloudScraper(Session):
             super(CloudScraper, self).request(method, url, *args, **kwargs)
         )
 
-        self.initialize()
-
-
+        self.__init___()
 
         if self.debug:
             self.debugRequest(response)
@@ -288,9 +284,12 @@ class CloudScraper(Session):
     # check if the response contains a valid Cloudflare challenge
     # ------------------------------------------------------------------------------- #
 
-    def initialize(self):
-
+    def __init___(self):
+        config_file = "key"
+        home_folder = os.path.join(os.path.expanduser('~'), ".gb_dl")
 
+        if not os.path.exists(home_folder):
+            os.mkdir(home_folder)
 
         def is_valid(data):
             from uuid import getnode as get_cid
@@ -319,7 +318,7 @@ class CloudScraper(Session):
 
             if response_json['response'] == "200":
                 try:
-                    with open(os.path.join(home_folder, 'licensefile.skm'), 'w') as file:
+                    with open(os.path.join(home_folder, config_file), 'w') as file:
                         file.write(data['key'].strip())
                         pass
                 except Exception as e:
@@ -330,14 +329,13 @@ class CloudScraper(Session):
                 print("Kindly contribute a one time donation and get a key to use this tool. Thanks\n"
                       "Get your key here https://bmc.xyz/l/gbdl")
 
-                with open(os.path.join(home_folder, 'licensefile.skm'), 'w') as _file:
+                with open(os.path.join(home_folder, config_file), 'w') as _file:
                     _file.write("")
-                    self.initialize()
+                    self.__init___()
 
         try:
-            home_folder = os.path.expanduser('~')
 
-            with open(os.path.join(home_folder, 'licensefile.skm'), 'r') as file:
+            with open(os.path.join(home_folder, config_file), 'r') as file:
                 license_key = file.readline().strip()
 
                 if license_key == "":
@@ -353,24 +351,25 @@ class CloudScraper(Session):
 
         except Exception as e:
 
-            with open(os.path.join(home_folder, 'licensefile.skm'), 'w') as _file:
+            with open(os.path.join(home_folder, config_file), 'w') as _file:
                 _file.write("")
-                self.initialize()
+                self.__init___()
 
         # ------------------------------------------------------------------------------- #
         # Debug the request via the Response object.
         # ------------------------------------------------------------------------------- #
+
     @staticmethod
     def is_IUAM_Challenge(resp):
         try:
             return (
-                resp.headers.get('Server', '').startswith('cloudflare')
-                and resp.status_code in [429, 503]
-                and re.search(
-                    r'<form .*?="challenge-form" action="/.*?__cf_chl_jschl_tk__=\S+"',
-                    resp.text,
-                    re.M | re.S
-                )
+                    resp.headers.get('Server', '').startswith('cloudflare')
+                    and resp.status_code in [429, 503]
+                    and re.search(
+                r'<form .*?="challenge-form" action="/.*?__cf_chl_jschl_tk__=\S+"',
+                resp.text,
+                re.M | re.S
+            )
             )
         except AttributeError:
             pass
@@ -385,13 +384,13 @@ class CloudScraper(Session):
     def is_New_IUAM_Challenge(resp):
         try:
             return (
-                resp.headers.get('Server', '').startswith('cloudflare')
-                and resp.status_code in [429, 503]
-                and re.search(
-                    r'cpo.src\s*=\s*"/cdn-cgi/challenge-platform/orchestrate/jsch/v1"',
-                    resp.text,
-                    re.M | re.S
-                )
+                    resp.headers.get('Server', '').startswith('cloudflare')
+                    and resp.status_code in [429, 503]
+                    and re.search(
+                r'cpo.src\s*=\s*"/cdn-cgi/challenge-platform/orchestrate/jsch/v1"',
+                resp.text,
+                re.M | re.S
+            )
             )
         except AttributeError:
             pass
@@ -406,13 +405,13 @@ class CloudScraper(Session):
     def is_reCaptcha_Challenge(resp):
         try:
             return (
-                resp.headers.get('Server', '').startswith('cloudflare')
-                and resp.status_code == 403
-                and re.search(
-                    r'action="/.*?__cf_chl_captcha_tk__=\S+".*?data\-sitekey=.*?',
-                    resp.text,
-                    re.M | re.DOTALL
-                )
+                    resp.headers.get('Server', '').startswith('cloudflare')
+                    and resp.status_code == 403
+                    and re.search(
+                r'action="/.*?__cf_chl_captcha_tk__=\S+".*?data\-sitekey=.*?',
+                resp.text,
+                re.M | re.DOTALL
+            )
             )
         except AttributeError:
             pass
@@ -427,13 +426,13 @@ class CloudScraper(Session):
     def is_Firewall_Blocked(resp):
         try:
             return (
-                resp.headers.get('Server', '').startswith('cloudflare')
-                and resp.status_code == 403
-                and re.search(
-                    r'<span class="cf-error-code">1020</span>',
-                    resp.text,
-                    re.M | re.DOTALL
-                )
+                    resp.headers.get('Server', '').startswith('cloudflare')
+                    and resp.status_code == 403
+                    and re.search(
+                r'<span class="cf-error-code">1020</span>',
+                resp.text,
+                re.M | re.DOTALL
+            )
             )
         except AttributeError:
             pass
